<?php
/**
 * This template displays the archive for Products
 *
 * Based on WooCommerce 1.5.5
 *
 * Note for customisers/users: Do not edit this file!
 * ==================================================
 * If you want to customise this template, copy this file (keep same name) and place the
 * copy in the child theme's woocommerce folder, ie themes/my-child-theme/woocommerce
 * (Your theme may not have a 'woocommerce' folder, in which case create one.)
 * The version in the child theme's woocommerce folder will override this template, and
 * any future updates to this plugin won't wipe out your customisations.
 *
 * @since 0.9.0
 *
 */

/** Remove default Genesis loop */
remove_action( 'genesis_loop', 'genesis_do_loop' );

/** Remove WooCommerce breadcrumbs */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

/** Uncomment the below line of code to add back WooCommerce breadcrumbs */
//add_action( 'genesis_before_loop', 'woocommerce_breadcrumb', 10, 0 );

/** Remove Woo #container and #content divs */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );


/** Get Shop Page ID */
global $shop_page_id;
$shop_page_id = get_option( 'woocommerce_shop_page_id' );


add_filter( 'genesis_pre_get_option_site_layout', 'genesiswooc_archive_layout' );
/**
 * Manage page layout for the Product archive (Shop) page
 *
 * Set the layout in the Genesis layouts metabox in the Page Editor
 *
 * @since 0.9.0
 *
 * @param str $layout Genesis layout, eg 'content-sidebar', etc
 * @global string|int $shop_page_id The ID of the Shop WP Page
 * @return str $layout Shop Page layout from postmeta
 */
function genesiswooc_archive_layout( $layout ) {

	global $shop_page_id;

	$layout = get_post_meta( $shop_page_id, '_genesis_layout', true );

	return $layout;
}

add_action( 'genesis_before_loop', 'genesiswooc_archive_product_loop' );
/**
 * Display shop items
 *
 * Uses WooCommerce structure and contains all existing WooCommerce hooks
 * Note that this will also display any content created in the Shop Page itself
 *
 * Code based on WooCommerce 1.5.5 woocommerce_archive_product_content()
 * @see woocommerce/woocommerce-template.php
 *
 * @uses woocommerce_get_template_part() since v0.9.3
 *
 * @since 0.9.0
 * @global string|int $shop_page_id The ID of the Shop WP Page
 */
function genesiswooc_archive_product_loop() {

	global $shop_page_id;

	if ( !is_search() ) :
			$shop_page = get_post( $shop_page_id );
			$shop_page_title = apply_filters( 'the_title', ( get_option( 'woocommerce_shop_page_title' ) ) ? get_option( 'woocommerce_shop_page_title' ) : $shop_page->post_title );
			$shop_page_content = $shop_page->post_content;
		else :
			$shop_page_title = __( 'Search Results:', 'woocommerce' ) . ' &ldquo;' . get_search_query() . '&rdquo;';
			if ( get_query_var( 'paged' ) ) $shop_page_title .= ' &mdash; ' . __( 'Page', 'woocommerce' ) . ' ' . get_query_var( 'paged' );
			$shop_page_content = '';
		endif;

	do_action( 'woocommerce_before_main_content' );
?>

	<h1 class="page-title"><?php echo $shop_page_title ?></h1>

	<?php echo apply_filters( 'the_content', $shop_page_content );

	// Revert to WooC's function for template parts since 0.9.3
	woocommerce_get_template_part( 'loop', 'shop' );

	do_action( 'woocommerce_pagination' );

	do_action( 'woocommerce_after_main_content' );
}

genesis();